==> gcloud-oauth-vue-0.1.0.tgz: package/src/router/index.js <==
import Vue from 'vue'
import Router from 'vue-router'
/* Layout */
import Layout from '@/layout'

const routerPush = Router.prototype.push
Router.prototype.push = function push (location) {
  return routerPush.call(this, location).catch(error => error)
}

Vue.use(Router)

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
let defaultRouters = [
  {
    path: '/',
    redirect: '/private/dashboard',
  },
  {
    path: '/login',
    name: 'login',
    hidden: true,
    component: () => import('../../packages/gcloud-login/src/main.vue')
  },
  {
    path: '/404',
    name: '404',
    hidden: true,
    component: () => import('@/views/404/index.vue'),
  },
  {
    path: '/dashboard',
    component: Layout,
    children: [
      {
        path: '/private/dashboard',
        component: () => import('@/views/index.vue'),
        name: 'dashboard',
        meta:{title :"驾驶舱" , affix:true }
      },
      {
        path: '/test',
        component: () => import('@/views/test/index.vue'),
        name: 'test',
        meta:{title :"测试页面", affix:false }
      },
    ]
  }
]

const createRouter = () => new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: defaultRouters
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
export  { defaultRouters }

==> gcloud-oauth-vue-0.1.2.tgz: package/src/router/index.js <==
import Vue from 'vue'
import Router from 'vue-router'
/* Layout */
import Layout from '../layout'

const routerPush = Router.prototype.push
Router.prototype.push = function push (location) {
  return routerPush.call(this, location).catch(error => error)
}

Vue.use(Router)

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
let defaultRouters = [
  {
    path: '/',
    redirect: '/private/dashboard',
  },
  {
    path: '/login',
    name: 'login',
    hidden: true,
    component: () => import('../../packages/gcloud-login/src/main.vue')
  },
  {
    path: '/404',
    name: '404',
    hidden: true,
    component: () => import('../views/404/index.vue'),
  },
  {
    path: '/dashboard',
    component: Layout,
    children: [
      {
        path: '/private/dashboard',
        component: () => import('../views/index.vue'),
        name: 'dashboard',
        meta:{title :"驾驶舱" , affix:true }
      },
      {
        path: '/test',
        component: () => import('../views/test/index.vue'),
        name: 'test',
        meta:{title :"测试页面", affix:false }
      },
    ]
  }
]

const createRouter = () => new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: defaultRouters
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
export  { defaultRouters }
